% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% % % % % % % % % % % % % % % % % SHORT COURSE ON MARINE DATA LITERACY  % % % % % % % % % % % 
% % % % % % % % % % % % INTRODUCTION TO SEA STATE AND WIND WAVE CHARACTERIZATION% % % % % % % 
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %%

%add path to the directory with the matlab rutines and script provided and generate the path for the subfolder
%CHANGE to your own path 
addpath(genpath('C:\Users\Tomas\Documents\DOCENCIA\SEAeu\SEAeuMDLcoursePS8')) 
% Change directory to the data folder
cd C:\Users\Tomas\Documents\DOCENCIA\SEAeu\DATA %CHANGE to your own path
% Define the path for the data folder

%%
%Inspection of file contents
%file info
finfo=ncinfo('r_ERA5_UVP_20190101.nc')
%Read and plot SWH
filen=fullfile('2019','r_ERA5_UVP_20190101.nc');
lon=ncread(filen,'longitude');
lat=ncread(filen,'latitude');
time=ncread(filen,'time');
t_unit=ncreadatt(filen,'time','units');
tjul=(time/24)+datenum(t_unit(13:end-2),'yyyy-mm-dd HH:MM:SS');
swh=ncread(filen,'swh');
%plot swh
pcolor(lon,lat,swh(:,:,2)');shading flat;
%set plot labels
title(['SWH  ', datestr(tjul(2))]);
xlabel('Longitude');
ylabel('Latitude');
%set colorbar
hc=colorbar;
title(hc,'SWH (m)')
%Define finelname and resolution for the figure
fileNameImage='SWH_example'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)

%%
% Read and plot a given date
dat_in='2019-01-23 03:00:00'
[val,in]= min(abs(tjul-datenum(dat_in,'yyyy-mm-dd HH:MM:SS')))
figure;
pcolor(lon,lat,swh(:,:,in)');shading flat;
hold on; %allows plot on top
%calculate the max of SWH in the area for the wiven date
dmap=squeeze(swh(:,:,in))';%Extract slice from 3D matrix correspoding to dat_in
SWHmax=max(dmap(:));%Calculate the maximum
% find the location of the maximum SWH
[X,Y]=meshgrid(lon,lat);
locMax=[X(find(dmap(:)==SWHmax))  Y(find(dmap(:)==SWHmax)) ]
plot(locMax(1),locMax(2),'+r')
%set plot labels
title(['Max SWH ',num2str(nanmax(SWHmax),'% 10.2f'),' m ' ,datestr(tjul(in))]);
xlabel('Longitude (ºE)')
ylabel('Latitude (ºN)')
%set colorbar
hc=colorbar
title(hc,'SWH (m)')
%Define finelname and resolution for the figure
fileNameImage='SWH_example2'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)


%CUESTIONS
% 1) Calculate the minimum of the swh filed for 20.01.2019 at 21h 
%% EXTRACT a subset and concatenate swh wave filed for the full period 2010-2020k
clear all; %clean workspace
close all; %close all figures
%Read lon and lat filed
filen=fullfile('2019','r_ERA5_UVP_20190101.nc')
lon=ncread(filen,'longitude');
lat=ncread(filen,'latitude');
swh=ncread(filen,'swh');

LonlatWindw=[-11 -5 32 39];
%SEARCH ALTYMETRY IN LAT LON WINDOW
        posLo=find(lon>=LonlatWindw(1)&lon<=LonlatWindw(2));       
        posLa=find(lat>=LonlatWindw(3)&lat<=LonlatWindw(4));
%Check subset
 figure;
 subplot(1,2,1)% prepare figure with two horizontal panel (left panel)
pcolor(lon,lat,swh(:,:,1)');axis equal;hold on
%plot selected window
plot([LonlatWindw(1) LonlatWindw(2) LonlatWindw(2) LonlatWindw(1) LonlatWindw(1)], ...
     [LonlatWindw(3) LonlatWindw(3) LonlatWindw(4) LonlatWindw(4) LonlatWindw(3)],'r')
%modify color scale 
caxis([0 3])
%insert title
title('Original')
 subplot(1,2,2)% prepare figure with two horizontal panel (right panel)
pcolor(lon(posLo),lat(posLa),swh(posLo,posLa,1)');axis equal;hold on
plot([LonlatWindw(1) LonlatWindw(2) LonlatWindw(2) LonlatWindw(1) LonlatWindw(1)], ...
     [LonlatWindw(3) LonlatWindw(3) LonlatWindw(4) LonlatWindw(4) LonlatWindw(3)],'r')
 caxis([0 3])
 title('Subset')
 %Define finelname and resolution for the figure
fileNameImage='SWH_subset'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)

%%  
% Extract subset and concatenate variables for the whole period
fl=dir('20*')%store the names of directories with that contain the data
swhAll=[]
timeAll=[];
for i=1:length(fl)
  fn= dir (fullfile(fl(i).name,'*.nc'))% store the names of the *.nc files of each directory 
  for j=1:length(fn) 
   
     filen= fullfile(fl(i).name,fn(j).name);
if i==1 & j==1    
lon=ncread(filen,'longitude');
lat=ncread(filen,'latitude');
end
time=ncread(filen,'time');
t_unit=ncreadatt(filen,'time','units');
tjul=(time/24)+datenum(t_unit(13:end-2),'yyyy-mm-dd HH:MM:SS');
swh=ncread(filen,'swh');

[m,n,o]=size(swhAll);
swhAll(:,:,o+1:o+length(tjul))=[swh(posLo,posLa,:)];
timeAll=[timeAll;tjul];
  end
end
swhAll=swhAll(:,:,2:end); %remove first field zeros added in first iteration

%% MEAN WAVE CLIMATE%%
% Basic Statistics
max_SWH = max(swhAll, [], 3);
min_SWH = min(swhAll,[], 3);
mean_SWH = mean(swhAll, 3);
med_SWH = median(swhAll, 3);
P99_SWH=prctile(swhAll,99,3);

% SEASONAL WAVE CLIMATE
tvec=datevec(timeAll);
SeasoN(1).Pos=find(tvec(:,2)==12 | tvec(:,2)==1 | tvec(:,2)==2);SeasoN(1).Label='DJF';%Winter:DJF
SeasoN(2).Pos=find(tvec(:,2)==3 | tvec(:,2)==4 | tvec(:,2)==5);SeasoN(2).Label='MAM';%Spring:MAM
SeasoN(3).Pos=find(tvec(:,2)==6 | tvec(:,2)==7 | tvec(:,2)==8);SeasoN(3).Label='JJA';%Summer:JJA
SeasoN(4).Pos=find(tvec(:,2)==9 | tvec(:,2)==10 | tvec(:,2)==11);SeasoN(4).Label='SON';%Autumm:SON
%Get limits for colorbar
for i=1:length(SeasoN);
  data=swhAll(:,:,SeasoN(i).Pos);
  posmat = mean(data,3);
  colorL(i,:)=[min(posmat(:)) max(posmat(:))];
end
 colorL= [min(colorL(:))   max(colorL(:))];
figure;
setColorLim=0% 0 set automatic color / 1 use color range
for i=1:length(SeasoN);
  data=swhAll(:,:,SeasoN(i).Pos);
  posmat = mean(data,3);
  subplot(2,2,i);
    pcolor(lon(posLo),lat(posLa),posmat');shading flat;axis equal
xlabel('Longitude (ºE)');
ylabel('Latitude (ºN)');
hc=colorbar
if setColorLim==1;
caxis(colorL);
end
title(hc,'SWH (m)')
title(SeasoN(i).Label)
end

 %Define finelname and resolution for the figure
fileNameImage='Seasonal_SWH'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)


%CUESTIONS
% 2) Calculate the median of the 99 percentile of the mean wave period for
% Summer season for the same subset

%% WAVE ENERGY FLUX
%WEF=((1025*9.81)/(64*pi))*mwpAll.*swhAll.^2

% Extract subset of Mean Wave Periodand concatenate variables for the whole period
fl=dir('20*')%store the names of directories with that contain the data
mwpAll=[]
mwdAll=[]

for i=1:length(fl)
  fn= dir (fullfile(fl(i).name,'*.nc'))% store the names of the *.nc files of each directory 
  for j=1:length(fn) 
     filen= fullfile(fl(i).name,fn(j).name);
mwp=ncread(filen,'mwp');
mwd=ncread(filen,'mwd');

time=ncread(filen,'time');
t_unit=ncreadatt(filen,'time','units');
tjul=(time/24)+datenum(t_unit(13:end-2),'yyyy-mm-dd HH:MM:SS');
[m,n,o]=size(mwpAll);
mwpAll(:,:,o+1:o+length(tjul))=[mwp(posLo,posLa,:)];
mwdAll(:,:,o+1:o+length(tjul))=[mwd(posLo,posLa,:)];
  end
end

mwpAll=mwpAll(:,:,2:end); %remove first field zeros added in first iteration
mwdAll=mwdAll(:,:,2:end); %remove first field zeros added in first iteration
%WEF=((1025.*9.81)./(64.*pi))*mwpAll.*swhAll.^2;
[m,n,o]=size(mwpAll)
for i=1:o
  WEF(:,:,i) = ((1025.*9.81)./(64.*pi)).*mwpAll(:,:,i).*swhAll(:,:,i).^2;
end
mean_WEF = mean(WEF,3);
mean_mwdAll=mean(mwdAll,3);

%Transform compass in to Cartesian coordinates
theta=[mean_mwdAll(:)];
rho=[mean_WEF(:)];
for i=1:length(rho)
 [um,vm] = compass2cart(theta(i),rho(i));
 if ~isempty(um)
 UV(i,:)=[um vm];
 else
    UV(i,:)=[NaN NaN]  
 end
end
Uswh=reshape(UV(:,1),size(mean_WEF));
Vswh=reshape(UV(:,2),size(mean_WEF));

%Plot MEAN WAVE FLUX direction
figure 
pcolor(lon(posLo),lat(posLa),mean_WEF');shading flat;axis equal%Plot magnitude
hold on
quiver(lon(posLo),lat(posLa),-Uswh',-Vswh','k')%Plot vector for MWF direction;

title('Mean WEF');
xlabel('Longitude (ºE)')
ylabel('Latitude (ºN)')
%set colorbar
hc=colorbar
title(hc,'WEF (W·m^{-1})')
 %Define finelname and resolution for the figure
fileNameImage='Mean_WaveEnergyFlux'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)

%% WORKING WITH TIME SERIES
%Extract time series of two coastal point 
%Define points locations
p1=[-5.8 36.2] %Spain;
p2=[-9 33] %Morroco;
xy=[p1;p2]
%Linear interpolation of wave characteristics into the location included in xy 
for i=1:o
  swhPoints(i,:)= griddata(double(lon(posLo)),double(lat(posLa)),swhAll(:,:,i)',xy(:,1),xy(:,2));
  mwdPoints(i,:)= griddata(double(lon(posLo)),double(lat(posLa)),mwdAll(:,:,i)',xy(:,1),xy(:,2));
  mwpPoints(i,:)= griddata(double(lon(posLo)),double(lat(posLa)),mwpAll(:,:,i)',xy(:,1),xy(:,2));
end
%%

% plot time series 
figure
%plot SWH
subplot(3,1,1);
plot(timeAll,swhPoints(:,2),'.-r');hold on;
plot(timeAll,swhPoints(:,1),'.-b');hold on;
title(['SWH (m) '],'FontName','Arial','fontweight','bold','fontsize',10,'color','k');
axis([timeAll(1) timeAll(end) min(swhPoints(:)) max(swhPoints(:))])
datetick('x','dd/mm/yyyy','keeplimits','keepticks');
set(gca,'XMinorTick','on')
set(gca,'XTick',[])
legend('SWH p2' , 'SWH p1','Location','northeastoutside')
%plot MWP   
subplot(3,1,2);
plot(timeAll,mwpPoints(:,2),'.-r');hold on;
plot(timeAll,mwpPoints(:,1),'.-b');hold on;
title(['Mean Wave Periodo (s) '],'FontName','Arial','fontweight','bold','fontsize',14,'color','k');
axis([timeAll(1) timeAll(end) min(mwpPoints(:)) max(mwpPoints(:))])
datetick('x','dd/mm/yyyy','keeplimits','keepticks');
set(gca,'XMinorTick','on')
legend('Tm p2','Tm p1','Location','northeastoutside')
    grid on
    set(gca,'XTick',[])
%plot MWD   
subplot(3,1,3);
% plot(date_num,SprTp,'.-g');hold on;
plot(timeAll,mwdPoints(:,2),'.r');hold on;
plot(timeAll,mwdPoints(:,1),'.b');hold on;
title(['Direccion '],'FontName','Arial','fontweight','bold','fontsize',14,'color','k');
axis([timeAll(1) timeAll(end) 0 360])
datetick('x','dd/mm/yyyy','keeplimits','keepticks');
set(gca,'Ytick',(0:45:360),'YtickLabel',{'N','NE','E','SE','S','SW','W','NW'});
set(gca,'XMinorTick','on')
legend('Dir p2','Dir p1','Location','northeastoutside')
grid on
    
%Define filename and resolution for the figure
fileNameImage='SWH_timeSeries'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)
  
%% Plot polar diagram Wave Rose
for i=1:length(xy(:,1))
mod=swhPoints(:,i);
dir=mwdPoints(:,i);  
hbins=(0:1:5)';
dbins=0 : 30 : 330;
fbins=[5:10:65];
figure
w = WindRose(gca, dir, mod,dbins ,hbins,fbins, ['Loc',num2str(i)]);
end
%Define filename and resolution for the figure
fileNameImage='SWH_WaveRose'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)

% CUESTIONS
% 3) Which is the most frecuent direction in the location -7.5W, 36.5?
%% WAVE CLIMATE SCALAR 
%Calculate the mean wave climate
%Prepare the time series
A=[datevec(timeAll)];
A=[A(:,1:4) swhPoints(:,1)];
m=min(A(:,5));
M=max(A(:,5));
%Prepare 
NPuntos=150;
[YY,prob]=DistribucionNPuntos(A(:,5),NPuntos);
y=log(YY);
dum=find(prob>=0.2 & prob<=0.9999);
x=norminv(prob,0,1);
n=length(x(dum));
xm=mean(x(dum));
ym=mean(y(dum));
Sxx=sum(x(dum).^2)-n*(xm)^2;  
Sxy=sum(x(dum).*y(dum))-n*xm*ym;
Syy=sum(y(dum).^2)-n*ym^2;
a1=Sxy/Sxx;
a0=ym-a1*xm;
z=a1*x(dum)+a0;
SSR=Sxy^2/Sxx;    
SSE=Syy-SSR;      
SST=SSR+SSE;      
R2=SSR/SST;      
mu=a0;
sigma=a1;
P=[0.001 0.01 0.05 0.2 0.5 0.8 0.95 0.99 0.999 0.9999];
P100=P*100;
r=length(P);
%PLOT the mean wave climate
figure
plot(x(dum),z,'-g','linewidth',1.5);
title('MEAN WAVE CLIMATE SWH');
xlabel('Probability of non excedence');
set(gca, 'xtick', norminv(P));
set(gca, 'xticklabel', P);
ylabel('SWH (m)');
yes=[floor(10*min(A(:,5)))/10:ceil(1*(max(A(:,5))-min(A(:,5))))/10:max(A(:,5))+(1*(max(A(:,5))-min(A(:,5))))/10];
DUM=find(yes~=0);
set(gca, 'ytick',log(yes(DUM)'));
set(gca, 'yticklabel', yes(DUM));
textLeg=strcat('P1' ,' \mu*=',num2str(mu,4),' \sigma*=',num2str(sigma,4),' R^2=',num2str(R2,4));
legend(textLeg);
grid on 

%Define filename and resolution for the figure
fileNameImage='SWH_LogNormal'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)


 %%
 %Joint Distriubtion swh and mwp
ht=[swhPoints(:,1) mwpPoints(:,1)]; %vector contaning swh and mwp for point 1
[scatterMag,XI,YI,PI] =density2scatter([100 100],ht,0);%calculate density of the mwp and swh pair
figure
pcolor(XI,YI,PI)
xlabel('swh (m)')
ylabel('mwp (s)')
hc=colorbar
title(hc,'Density')

%Calculate the most frequent combination of Hs-Tp value and display in the command window
[val,in]=max(PI(:));
disp(['Max. Density for Hs ', num2str(XI(in)), ', Tp ', num2str(YI(in)) ,' pair'])


%Define filename and resolution for the figure
fileNameImage='swh_mwp_JointDistribution'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)


%% EXTREME WAVE CLIMATE 
%Add the path to your unziped tsEva* folder noot needed if you already unzip 
addpath (genpath('C:\Users\Tomas\Documents\SCRIPT_MATLAB\tsEva-0.1_R2014b'))%CHANGE to yourpath

timeAndSeries = [timeAll swhPoints(:,1)];%create the time sieres
minPeakDistanceInDays = 3;%Indicates the peak distance (in days)  to be considered an independent event 
disp('stationary fit of extreme value distributions (GEV, GPD) to a time series');
statEvaParams = tsEvaStationary(timeAndSeries, 'minPeakDistanceInDays', minPeakDistanceInDays);
[hndl,returnPeriods, returnLevels, retrunLevelsErrs]= tsEvaPlotReturnLevelsGPDFromAnalysisObj(statEvaParams,1);
close all;


%computeError
supRLCI = returnLevels + 2*retrunLevelsErrs;
infRLCI = returnLevels - 2*retrunLevelsErrs;
  maxRL = max(supRLCI);
  minRL = min(infRLCI);
%plot results
f = figure;
phandles{1} = f;
f.Position = [0, 0, 1300, 700] + 10;
h = area(returnPeriods, cat(1, infRLCI, supRLCI - infRLCI)', 'linestyle', 'none');
h(1).FaceColor = [1,1,1];
h(2).FaceColor = [0.5 0.5 0.5];
hold on;
phandles{2} = h;
phandles{3} = plot(returnPeriods, returnLevels, 'color', [0 0 0], 'linewidth', 3);
hold on;
set(gca, 'Xscale', 'log');
ylim([minRL maxRL]);
xlim([min(returnPeriods), max(returnPeriods)]);
grid on;
set(gca,'layer','top');
set(gca, 'fontsize', 20);
xlabel('return periods', 'fontsize', 24);
ylabel('swh (m)', 'fontsize', 24);
title ('Extreme wave climate Loc 1');

%Define filename and resolution for the figure
fileNameImage='EVA_Location1'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)

%%  Longer time series is requested to compute extreme wave climate
DAT=load('timeAndSeries_waves_015_220E_055_509N');
timeAndSeries = [DAT.timeAndSeries];
minPeakDistanceInDays = 3;%Indicates the peak distance (in days)  to be considered an independent events 
disp('stationary fit of extreme value distributions (GEV, GPD) to a time series');
statEvaParams = tsEvaStationary(timeAndSeries, 'minPeakDistanceInDays', minPeakDistanceInDays);
[hndl,returnPeriods, returnLevels, retrunLevelsErrs]= tsEvaPlotReturnLevelsGPDFromAnalysisObj(statEvaParams,1);
close all
%computeError
supRLCI = returnLevels + 2*retrunLevelsErrs;
infRLCI = returnLevels - 2*retrunLevelsErrs;
  maxRL = max(supRLCI);
  minRL = min(infRLCI);
%plot results
f = figure;
phandles{1} = f;
f.Position = [0, 0, 1300, 700] + 10;
h = area(returnPeriods, cat(1, infRLCI, supRLCI - infRLCI)', 'linestyle', 'none');
h(1).FaceColor = [1,1,1];
h(2).FaceColor = [0.5 0.5 0.5];
hold on;
phandles{2} = h;
phandles{3} = plot(returnPeriods, returnLevels, 'color', [0 0 0], 'linewidth', 3);
hold on;
%addlines in the confidence interval
% phandles{4} = plot(returnPeriods, supRLCI, 'color', [0.2 0.2 0.8],'linewidth', 2);
% phandles{5} = plot(returnPeriods, infRLCI, 'color', [0.2 0.2 0.8],'linewidth', 2);
set(gca, 'Xscale', 'log');
ylim([minRL maxRL]);
xlim([min(returnPeriods), max(returnPeriods)]);
grid on;
set(gca,'layer','top');
set(gca, 'fontsize', 20);
xlabel('return periods', 'fontsize', 24);
ylabel('swh (m)', 'fontsize', 24);
title ('Extreme wave climate 15,22E 55,509N');
%Define filename and resolution for the figure
fileNameImage='EVA_LongTimeSeries'% indicate the finename 
resImage='-r300'%Indicate the resolution dpi
%Save the image
print('-dpng',resImage,fileNameImage)


